# Erstellen von JSON Web Keys für Testzwecke
FIT-Connect verwendet zur Übertragung von Antragsdaten und Metadaten mit direktem Bezug zu Anträgen eine Ende-zu-Ende-Verschlüsselung. Diese ist auf Basis des Standards [JSON Web Encryption (JWE)](https://tools.ietf.org/html/rfc7516) unter Verwendung von Schlüsseln gemäß des Standards [JSON Web Keys (JWK)](https://tools.ietf.org/html/rfc7517) umgesetzt.
Im Folgenden soll die Erstellung von JWKs mithilfe eines einfachen in Python geschriebenen Skriptes unter Windows und Linux erläutert werden.

## Voraussetzungen
Die Ausführung des Skriptes setzt eine installierte Version von [Python]( https://www.python.org/) voraus. Zum Nachinstallieren von benötigten Paketen wird Paketverwaltungsprogramm **pip** benötigt. Bei Versionen vor 3.4 ist ggf. noch eine manuelle Installation erforderlich.

### Windows
Eine Anleitung zur Installation und Einrichtung unter Windows finden Sie unter [Installationsanleitung Python Windows]( https://docs.microsoft.com/de-de/windows/python/beginners). 

### Linux
Der Ablauf und die Befehle zur Installation und Einrichtung von Python unter Linux unterscheiden sich je nach verwendeter Distribution. 

#### Für Ubuntu 
[Installationsanleitung Python Ubuntu]( https://docs.python-guide.org/starting/install3/linux/) 

Installation von **pip**
```console
foo@bar:~$ sudo apt install python3-pip
```

#### Für Debian 
[Installationsanleitung Python Debian]( https://linuxize.com/post/how-to-install-python-3-9-on-debian-10/) 

Installation von **pip**
```console
foo@bar:~$ sudo apt install python3-pip
```

#### Für Fedora
[Installationsanleitung Python Fedora]( https://developer.fedoraproject.org/tech/languages/python/multiple-pythons.html) 

```console
foo@bar:~$ yum -y install python-pip
```

### Erforderliche Python Pakete installieren
Um das Skript zur Erstellung von JSON Web Keys auszuführen, werden zusätzliche Python Pakete benötigt. Diese lassen sich jedoch sehr einfach mithilfe von **pip** nach-installieren. Dazu kann unter Windows die **PowerShell** sowie **Terminal** unter Linux verwendet werden.

Windows PowerShell:
```console
PS C:\> pip install jwcrypto
```

Linux:
```console
foo@bar:~$ pip install jwcrypto
```

### Herunterladen des Python-Skrips
Das Skript zur Erstellung der JSON Web Keys können Sie unter [Python Skript zur JWK-Erstellung](https://git.fitko.de/fit-connect/fit-connect-tools/-/blob/main/set-jwkset-gen.py) herunterladen. Speichern Sie es in einem Verzeichnis, in dem Sie das Skript später wiederfinden.

## Ausführung des Skripts
Navigieren Sie zum Verzeichnis in dem Sie das Python-Skript hinterlegt haben und öffnen Sie dort unter Windows eine **PowerShell** bzw. unter Linux ein **Terminal**. Alternativ können Sie auch innerhalb der **PowerShell** oder des **Terminals** zum Verzeichnis navigieren.
Mit dem folgenden Befehl kann das Python-Skript zur Erstellung der JSON Web Keys ausgeführt werden.

Windows PowerShell:
```console
PS C:\> python3 set-jwkset-gen.py
```

Linux:
```console
foo@bar:~$ python3 .\set-jwkset-gen.py
```
In der Konsole wird dann im Erfolgsfall der Speicherort der Schlüssel ausgegeben

```console
Wrote JWK representation of encryption public key (key_use=wrapKey) to C:\Users\username\AppData\Local\Temp\tmpx8gi90tq\publicKey_encryption.json
Wrote JWK representation of signature validation public key (key_use=verify) to C:\Users\username\AppData\Local\Temp\tmpx8gi90tq\publicKey_signature_verification.json
Please upload these keys when creating a destination in the self service portal.

Wrote JWKS of Public Keys to C:\Users\username\AppData\Local\Temp\tmpx8gi90tq\set-public-keys.json
This key set can be used to update (rotate) keys via the Submission-API (PUT /destinations/\{destinationID\})

Wrote JWK representation of decryption private key (key_use=unwrapKey) to C:\Users\username\AppData\Local\Temp\tmpx8gi90tq\privateKey_decryption.json
Wrote JWK representation of signing private key (key_use=sign) to C:\Users\username\AppData\Local\Temp\tmpx8gi90tq\privateKey_signing.json
These keys can be used to sign and decrypt in your client application.


```
