# Aufbau einer Einreichung

Der zentrale Anwendungsfall der Submission API besteht darin, Daten im Rahmen von Verwaltungsverfahren an hoheitliche Stellen (Behörden, Handelskammern, etc.) zu übermitteln.
Diese Daten werden durch Kunden und Verfahrenspartner übermittelt, um Verfahren (bspw. über einen Antrag) zu starten oder um Berichtspflichten zu erfüllen.

Diese Datenübermittlung wird in der Submission API als Einreichung (`submission`) bezeichnet und besitzt eine festgelegte Struktur aus Datenobjekten, die über die Ressourcen
der Submission API abgebildet werden. Mit dieser Struktur soll eine standardisierte Verarbeitung und Interpretation der einzelnen Bestandteile einer Einreichung ermöglicht werden.

Einreichung können aus fachlicher Sicht Anträge (bspw. ein strukturierter Datensatz mit den Daten eines Wohngeldantrags und Anlagen in beliebigen Datenformaten wie einer Urkunde als PDF), Berichte (bspw. ein Datensatz wie eine elektronische Bilanz in einem festlegten Berichtsformat für Statistik- oder Sozialmeldenungen) oder sonstige prozessauslösende Datensätze sein, die an Systeme von hoheitlichen Stellen übermittelt werden.

## Wie ist eine Einreichung aufgebaut?

![Struktur einer Einreichung](../../static/images/schema_reference/submission_structure.svg)

Eine Einreichung, die über die Submission API übermittelt wird, besteht aus drei Bestandteilen:
- Ein optionaler Fachdatensatz (`data`), der die Daten eines Antrags oder Berichts enthält und einem im Zustellpunkt vorgegebenen Datenschema (`submissionSchema`) entspricht.
- Eine oder mehrere optionale Anlagen (`attachments`) ergänzend zum Fachdatensatz. Die können Nachweise in Form von PDF-Urkunden, Bauanlagen wie XPlanGML-basierte Baupläne oder auch technische Laufzettel vom sendenden System sein.
- Ein obligatorischer Metadatensatz `metadata`), der die Einreichung beschreibt und zusammen mit der Submission API im Rahmen von FIT-Connect standardisiert wird.
Dieser enthält Strukturinformationen zum Fachdatensatz und Anlagen sowie prozessrelevante Informationen wie die Authentizierung des Absenders, Zahlungsinformationen (z.B. von Verfahrensgebühren) oder Rückkanalwünschen. 

## Wie stimmen sich sendende und empfangende Systeme beim Inhalt einer Einreichung ab?

In der Submission API wird durch das empfangende System über eine Schemaferenz im Zustellpunkt ein konkretes Schema für den Fachdatensatz festgelegt, den das sendende System übersenden darf. Eine Fachschemareferenz besteht aus zwei Angaben:
- Die `schemaURI` referenziert das zu verwendende Fachschema.
- Der `mimeType` gibt den Datentyp (JSON oder XML) des Fachdatensatzes vor.

In den Angaben eines Zustellpunkts befindet sich die Fachschemareferenz immer innerhalb eines Service-Objekts innerhalb des `services` Arrays.
Die Fachschemarefenz ist im Zustellpunkt daher immer einer dazugehörigen Leistung zugeordnet.

```json
"services":[
   {
      "identifier":"urn:de:fim:leika:leistung:99010003001006",
      "submissionSchemas":[
         {
            "schemaURI":"https://schema.fitko.de/fim/s00000121_1.0.0.schema.json",
            "mimeType":"application/json"
         }
      ],
      "regions":[
         "DE094750156156",
         "DE09330411"
      ]
   },
   {
      ...
      "submissionSchemas":[
         {
            "schemaURI":"https://schema.fitko.de/fim/s00000000009_1.1.0.schema.json",
            "mimeType":"application/json"
         },
         {
            "schemaURI":"https://schema.fitko.de/fim/s00000000010_1.0.0.schema.json",
            "mimeType":"application/json"
         }
      ],
      ...
   }
   ]

```

Wenn ein sendendes System die Angaben eines Zustellpunkts ermittelt (bspw. über [GET /destinations/{destinationId}](../apis/delivery-service.mdx#get-/destinations/-destinationId-) oder zukünftig die Routing API), so muss der Fachdatensatz diesem Schema entsprechen. 
Wenn mehrere Schemata (bspw. innerhalb des `submissionSchemas` Array) im Zustellpunkt referenziert werden, so muss der Fachdatensatz einem dieser referenzierten Schemata entsprechen.

## Warum muss das sendende System über den Metadatensatz eine Fachschemareferenz mitliefern?

Zusätzlich muss das sendende System eine identische Fachschemareferenz in den Metadatensatz der Einreichung für das Schema angeben, dem der übersendete Fachdatensatz entspricht.

```json
"contentStructure": {
  "data": {
    "submissionSchema": {
      "schemaURI": "https://schema.fitko.de/fim/s00000000009_1.0.0.schema.json",
      "mimeType": "application/json"
    }
  }
}
```

Insbesondere wenn ein empfangendes System viele unterschiedliche Schemata über den Zustellpunkt unterstützt, hilft diese Angabe bei der effizienten Validierung des Fachdatensatzes. Dies ist insbesondere dann relevant, wenn keine eindeutige Schemareferenz im Fachdatensatz enthalten ist.

## Sind Vorgaben für die Anzahl der Anlagen und deren Format möglich?

Aktuell sind keine konkreten Vorgaben für die Anzahl und das Format der Anlagen durch ein empfangendes Sytem über die Angaben im Zustellpunkt möglich. 
Aktuell existieren lediglich Vorgaben für die Gesamtgröße einer Einreichung (Fachdatensatz+Anlagen), die den Umfang der Anlagen hinsichtlich der Datengrößen begrenzen.
Für sonstige technische Vorgaben für Anlagen wird aktuell davon ausgegangen, dass die Fachstandards, zu denen ein genutzter Fachdatensatz gehört, technische Vorgaben für Anlagen machen. Ansonsten sollte ein empfangendes System im Mimimum PDF als Format für Anlagen akzeptieren.

Es wird für sendende Systeme empfohlen, auf den Versand eigener proprietärer Anlagen zu verzichten, wenn deren Nutzung nicht explizit mit den empfangenden Stellen abgestimmt wurde.

## Meine Software übermittelt oder empfängt nach Standard XYZ Fachdatensätze, wie kann ich das jeweils genutzte Fachschema korrekt referenzieren?

Eine Erläuerung der Schemareferenzen für die gängigsten Fachstandards der Verwaltung findet sich [hier](/details/schema-reference.md).
