---
title: Einführung in FIT-Connect
slug: /
---

Willkommen im FIT-Connect-Dokumentationsportal der FITKO.
Auf den folgenden Seiten werden die nötigen Schritte zur Anbindung an FIT-Connect und die FIT-Connect-Schnittstellen (APIs) beschrieben.
Die FIT-Connect Submission API baut auf dem bestehenden IT-Planungsrat Standard XFall auf und bietet Lösungsverantwortlichen von sendenden und empfangenden Systemen eine einfache Möglichkeit, ihre Software schnell und wirtschaftlich in länder- und ebenenübergreifende Antragsprozesse zu integrieren.
Die FIT-Connect Routing API soll es bundesweit ermöglichen, die richtigen Empfangspunkte für jeden Leistungs- und Zuständigkeitskontext zu ermitteln und soll die Submission API ergänzen.

## Was ist die FIT-Connect Submission API und was unterscheidet diese API vom bisherigen XFall-Standard?

Die FIT-Connect Submission API baut auf den bisherigen Konzepten und Erfahrungen des bestehenden IT-Planungsrats Standards XFall
auf.

> Die übergreifende Zielstellung des Standards XFall besteht darin, Anträge und Berichte, die aus vorgelagerten Systemen (bspw. Onlineantragsdienste, Fachportale oder Berichtssysteme) erstellt werden, in die unterschiedlichen Systeme der elektronischen Verfahrensbearbeitung (bspw. Fachverfahren, Dokumentenmanagementsystem oder Prozessplattformen) zu übergeben.

Bei der Entwicklung der Submission API wurden viele Konzepte mit Hinblick auf die neuen Erfordernisse des
Onlinezugangsgesetzes, der SDG-Verordnung sowie den Anforderungen digitaler Geschäftsmodelle weiterentwickelt. Technisch
setzt die FIT-Connect Submission API auf einen leichtgewichtigen RESTful-Architekturstil und baut auf der föderalen
Antragsübertragungsarchitektur von FIT-Connect auf. Bereitgestellt wird diese API durch einen zentral gemanagten Intermediär 
(`FIT-Connect Zustelldienst`), der für Nutzer der API einen Aufbau eigener Infrastruktur unnötig macht.

## Was macht die FIT-Connect Submission API und wie kann diese genutzt werden?

Die FIT-Connect Submission API ist als ein universelles Eingangstor für digitale Einreichungen an die Verwaltung ausgelegt:

- Empfangende Systeme (bspw. Fachverfahren oder E-Akte Systeme) können einen digitalen Zugang (Zustellpunkt) eröffnen und hierüber beliebige Einreichungen (Anträge, 
Berichtsmeldung, etc. ) erhalten. Was empfangen wird, kann über eindeutige Schema Referenzen auf Fachstandards festgelegt werden.
- Sendende Systeme (bspw. Antragsdienste) können Einreichungen an alle existierenden Zustellpunkte senden.
Um die richtigen Zustellpunkte für den jeweiligen Leistungskontext und die jeweilige Zuständigkeit zu finden, wird sendenden Systemen eine Routing API bereitgestellt.
Mit der Routing API können sendende Systeme auf Basis des Leistungs- und Ortsbezugs der Einreichung den richtigen Zustellpunkt ermitteln und alle technischen Verbindungsparameter ermitteln.

Die Vertraulichkeit der Übermittlung ist jederzeit gewährt, da eine Ende-zu-Ende-Verschlüsselung standardmäßig für alle übermittelten Daten vorgesehen ist und bis in den Browser oder das Endgerät der Antrag- oder Berichtssteller:in möglich ist.

### Zusammenspiel der Infrastruktur bei der Übermittlung von Einreichungen

![Applicationtransfer_Architecture](/images/api_overview/XFall_Integration_Architecture.png "Antragsübertragungsarchitektur FIT-Connect")

Über die Submission API können die zuständigen Stellen für ihre Systeme einen Zustellpunkt eröffnen, der
über eine `destination-Id` eindeutig adressierbar ist. Für diese Zustellpunkte legen die zuständigen Stellen alle
fachlichen Vorgaben (Zulässige Fachstandards, Verschlüsselung, Datenformate etc.) fest, damit eine medienbruchfreie
Weiterverarbeitung in ihren Systemen gewährleistet ist. Über die Angabe der `destination-Id` in
der Submission API können sendende Systemen Einreichungen an die zuständige Stelle senden.

Dieser Zustellpunkt ist jedoch vorab für eine Verwaltungsleistung und den jeweiligen örtlichen Antragskontext (bspw. Ort
der Antragsstellung) korrekt zu ermitteln. Damit die Ermittlung des korrekten Zustellpunkts skalierbar für das ganze
Bundesgebiet funktioniert, ist es vorgesehen, die `destinationId` in den Leistungs- und
Zuständigkeitsinformationen des lokalen FIM Leistungsredaktionssystems zu hinterlegen. Diese dezentral gepflegten
IDs werden durch das Online-Gateway (<https://www.onlinezugangsgesetz.de/Webs/OZG/DE/umsetzung/portalverbund/online-gateway/online-gateway-node.html>)
gebündelt. Fragt nun ein sendendes System über die Routing API an, ermittelt der FIT-Connect Routingdienst die korrekte `destination-Id` im Onlinegateway,
ruft auf Basis dieser ID die technischen Verbindungsparameter im DVDV ab und sendet diese Informationen an das sendende System zurück.

## Für wen ist die FIT-Connect Submission API gedacht und warum sollte ich sie nutzen?

Die FIT-Connect Submission API ist für alle Hersteller, Entwickler und Verfahrensverantwortliche von sendenden und empfangenden
Systemen gedacht. Insbesondere folgende Systeme mit bundesweiten Nutzungsszenarien sollen mit der FIT-Connect Submission API
unterstützt werden:

- **Einer für alle (EfA) Verfahren**: Länderübergreifend entwickelte Antragsverfahren für eine bestimmte
  Verwaltungsleistung oder ein Leistungsbündel, die entweder in verschiedenen Ländern nachnutzbar betrieben werden oder
  länderübergreifend als gemeinsamer Antragsdienst für alle zuständigen Stellen betrieben werden.
- **Antragsgeneratoren / Antragsmanagementsysteme**: Standardsoftware zur Erstellung und dem Betrieb von direkt
  nutzbaren Onlineantragsdiensten, die im ganzen Bundesgebiet bei einzelnen Stellen oder Gebietskörperschaften (bspw.
  als Basiskomponente) im Einsatz sind.
- **Als Standardsoftware bereitgestellte Fachverfahrenssoftware, Prozessplattformen oder Dokumentenmanagementsysteme**:
  Bundesweit angebotene und eingesetzte Standardsoftware, die von den zuständigen Stellen für die Antragsbearbeitung
  eingesetzt wird.

Für diese Systeme bietet die FIT-Connect bei der schnellen und wirtschaftlichen Realisierung medienbruchfreier
Antragsprozesse eine Reihe von Mehrwerten:

- **Plug and Play Anbindung an die föderale Antragsübermittlung**: Durch die zentral bereitgestellten APIs und die
  Nutzung der bestehenden Zuständigkeitsfinderinfrastruktur können Systeme schnell an eine föderale
  Antragsübermittlungsinfrastruktur angebunden werden, ohne eigene Infrastrukturen hierfür zu beauftragen oder
  aufzubauen.
- **Leichgewichtige APIs und Industriestandards**: Die FIT-Connect-Schnittstellen bauen auf leichgewichtigen RESTful API-Ansätzen
  auf und nutzt verbreitete Industriestandards wie den OpenAPI-Spezifikationsstandard und das OAuth-2.0-Autorisierungsframework, sodass kein spezialisiertes
  Know-How und spezifische Softwarekomponenten für die Anbindung erforderlich sind.
- **Flexibilität in der Antragsübermittlung**: Die FIT-Connect APIs verbinden Flexibilität und Standardisierung. Während
  die FIT-Connect Submission API eine einheitliche Metadatenstruktur festlegt, um Einreichungen strukturiert zu verarbeiten, können
  beliebige Fachstandards und Anhänge übertragen werden. Auch die Übertragung von Einreichungen im PDF-Format ist möglich,
  solange für die Antragsdaten noch kein FIM-Schema vorhanden ist.
  **Nutzung bestehender Prozesse und Strukturen für die Pflege von Adressierungsinformationen**: Langjährig erprobte
  Prozesse und Strukturen zur Pflege der Zuständigkeitsinformationen, können in den zuständigen Stellen beibehalten
  werden. Technische Adressierungsparameter werden über die gleichen Systeme und Prozesse gepflegt,
  die schon heute bei Informationen zu Anschriften, Rufnummern, E-Mail-Adressen oder Ansprechpartnern genutzt werden.
- **Machine2Machine Ready**: Die FIT-Connect Submission API und die FIT-Connect Antragsübermittlungsarchitektur sind von Grund auf
  als offene API-Plattform konzipiert. Dadurch können auch verwaltungsexterne Antrags- und Berichtssysteme wie
  Drittsoftware oder Unternehmenssysteme direkt eingebunden werden, ohne das hierfür eine gesonderte Infrastruktur
  notwendig ist.

### Ist die FIT-Connect Submission API nur für länder- und behördenübergreifende Antragskontexte gedacht?

Durch die einfache Anbindung und Nutzung bietet sich die Submission API auch dort an, wo das behördeneigene
Antragsverfahren mit dem behördeneigenen Fachverfahren verbunden wird. Durch die Nutzung der Submission API werden
diese Systeme standardisiert verbunden, ohne das die Behörde in Abhängigkeiten zu proprietären Technologien und
Schnittstellen gerät. Dies ermöglicht es der Behörde, ihre Systeme auf beiden Seiten flexibel auszutauschen und
weiterzuentwickeln, um somit auf neue technische Trends und Möglichkeit schnell zu reagieren.

## In welchem Stand befindet sich FIT-Connect Submission API und wann kann man diese nutzen?

Ein Zugang für interessierte Enwickler zur einer Testinfrastruktur ist seit August 2021 möglich.
Um auf diese Testumgebung zuzugreifen, können interessierte Entwickler ihre Anwendungen das Self-Service-Portal vorab registrieren.
Projektpartner können die API und Infrastruktur für produktive Datenübermittlungen ab September 2021 nutzen.
Detailerte Zeitpläne können der [Roadmap](https://docs.fitko.de/fit-connect/docs/roadmap) entnommen werden.
Updates werden regelmäßig im Bereich [News](https://docs.fitko.de/fit-connect/news) mitgeteilt.

## Ich habe einen Fehler in der Dokumentation oder in der API-Spezifikation gefunden. Wo kann ich diesen melden? {#found-bug}

Vielen Dank für das Interesse an unserer Entwickler:innendokumentation! Wir freuen uns immer über Feedback und
Anregungen über unser Funktionspostfach fit-connect ät fitko.de. Zudem können wir bei Interesse gerne einen Zugang zu
unserem GitLab zur Eröffnung von Issues oder Einreichung von Merge-Requests einrichten.
