import com.nimbusds.jose.*;
import com.nimbusds.jose.crypto.RSAEncrypter;
import com.nimbusds.jose.jwk.RSAKey;

import java.io.IOException;
import java.io.InputStream;
import java.security.interfaces.RSAPublicKey;
import java.text.ParseException;

public class Encrypt {

    static InputStream existingPublicKey = Encrypt.class.getClassLoader().getResourceAsStream("keys/examplePublicKey.json");
    static InputStream smallFile = Encrypt.class.getClassLoader().getResourceAsStream("txt250kb.txt");

    static RSAPublicKey publicKey;

    public static void main(String[] args) {
        String publicKeyAsString;

        try {
            publicKeyAsString = new String(existingPublicKey.readAllBytes());
            // Only RSA keys with RSA-OAEP-256 and A256GCM are allowed 
            // => Therefore we need to parse a RSAKey
            publicKey = RSAKey.parse(publicKeyAsString).toRSAPublicKey();

            System.out.println(publicKeyAsString);

            encryptText();
            encryptFile();
        } catch (IOException | ParseException | JOSEException e) {
            e.printStackTrace();
        }

    }

    private static void encryptText() {
        // Only RSA keys with RSA-OAEP-256 and A256GCM are allowed
        JWEHeader header = new JWEHeader(JWEAlgorithm.RSA_OAEP_256, EncryptionMethod.A256GCM);
        Payload payload = new Payload("Hello World");

        JWEObject jweObject = new JWEObject(header, payload);

        try {
            // Only RSA keys with RSA-OAEP-256 and A256GCM are allowed 
            // => Therefore we need to encrypt through RSAEncrypter
            jweObject.encrypt(new RSAEncrypter(publicKey));
        } catch (JOSEException e) {
            e.printStackTrace();
        }

        // Serialization according to JWE Compact Serialization (https://datatracker.ietf.org/doc/html/rfc7516#section-3.1)
        String encrypted = jweObject.serialize();

        System.out.println("Encrypted Text:");
        System.out.println(encrypted);
    }

    private static void encryptFile() {
        // Only RSA keys with RSA-OAEP-256 and A256GCM are allowed
        JWEHeader header = new JWEHeader(JWEAlgorithm.RSA_OAEP_256, EncryptionMethod.A256GCM);

        try {
            Payload payload = new Payload(smallFile.readAllBytes());
            JWEObject jweObject = new JWEObject(header, payload);

            // Only RSA keys with RSA-OAEP-256 and A256GCM are allowed 
            // => Therefore we need to encrypt through RSAEncrypter
            jweObject.encrypt(new RSAEncrypter(publicKey));

            // Serialization according to JWE Compact Serialization (https://datatracker.ietf.org/doc/html/rfc7516#section-3.1)
            String encrypted = jweObject.serialize();

            System.out.println("Encrypted File:");
            System.out.println(encrypted);
        } catch (IOException | JOSEException e) {
            e.printStackTrace();
        }
    }
}
