import com.nimbusds.jose.*;
import com.nimbusds.jose.crypto.RSASSASigner;
import com.nimbusds.jose.jwk.JWK;
import com.nimbusds.jose.jwk.JWKSet;
import com.nimbusds.jwt.JWTClaimsSet;
import com.nimbusds.jwt.SignedJWT;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.text.ParseException;
import java.util.Date;
import java.util.Locale;
import java.util.Map;
import java.util.UUID;

public class GenerateSignedToken {

    private static final InputStream jwksPath = GenerateSignedToken.class.getClassLoader().getResourceAsStream("jwks.json");;
    private static final UUID signatureKeyId = UUID.fromString("6508dbcd-ab3b-4edb-a42b-37bc69f38fed");

    private static final String subject = "submission:f65feab2-4883-4dff-85fb-169448545d9f";
    private static final String event = "https://schema.fitko.de/fit-connect/events/accept-submission";
    private static final String transactionId = "case:f73d30c6-8894-4444-8687-00ae756fea90";


    public static void main(String[] args) {
        try {
            JWKSet localKeys = JWKSet.load(jwksPath);
            JWK key = localKeys.getKeyByKeyId(signatureKeyId.toString());

            System.out.println(signatureKeyId);
            System.out.println(localKeys);

            if (key == null) {
                throw new RuntimeException("Cannot find key with specified Key Id");
            }

            JWSSigner signer = new RSASSASigner(key.toRSAKey());
            JWTClaimsSet claimsSet = new JWTClaimsSet.Builder()
                    // ToDO: Inject configured domain in stack
                    .issuer("https://api.fitko.de/fit-connect/")
                    .issueTime(new Date())
                    .jwtID(UUID.randomUUID().toString())
                    .subject(subject)
                    .claim("events", Map.of(event, Map.of()))
                    .claim("txn", transactionId)
                    .build();

            JWSHeader header = JWSHeader.parse(Map.of(
                    "typ", "secevent+jwt",
                    "kid", key.getKeyID(),
                    "alg", "PS512"
            ));

            SignedJWT signedJWT = new SignedJWT(
                    header,
                    claimsSet);

            signedJWT.sign(signer);

            System.out.println(signedJWT.serialize());
        } catch (IOException | ParseException e) {
            e.printStackTrace();
            throw new RuntimeException("Error during loading of JWK-Set with signature keys.");
        } catch (JOSEException e) {
            e.printStackTrace();
            throw new RuntimeException("Could not generate SET");
        }
    }
}
